@@ -1,4 +1,4 @@
-/* Copyright (C) 2006-2020 J.F.Dockes
+/* Copyright (C) 2006-2022 J.F.Dockes
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -53,6 +53,8 @@
 
 using namespace std;
 
+namespace MedocUtils {
+
 int stringicmp(const string& s1, const string& s2)
 {
     return strcasecmp(s1.c_str(), s2.c_str());
@@ -318,10 +320,34 @@ template <class T> void stringsToCSV(const T& tokens, string& s, char sep)
         s.append(1, sep);
     }
     // Remove last separator.
-    if (s.size())
+    if (!s.empty())
         s.pop_back();
 }
 
+template <class T> std::string commonprefix(const T& values)
+{
+    if (values.empty())
+        return std::string();
+    if (values.size() == 1)
+        return *values.begin();
+    unsigned int i = 0;
+    for (;;i++) {
+        auto it = values.begin();
+        if (it->size() <= i) {
+            goto out;
+        }
+        auto val = (*it)[i];
+        it++;
+        for (;it < values.end(); it++) {
+            if (it->size() <= i || (*it)[i] != val) {
+                goto out;
+            }
+        }
+    }
+out:
+    return values.begin()->substr(0, i);
+}
+
 #ifdef SMALLUT_EXTERNAL_INSTANTIATIONS
 #include "smallut_instantiate.h"
 #else
@@ -342,12 +368,12 @@ template string stringsToString<vector<string> >(const vector<string>&);
 template string stringsToString<set<string> >(const set<string>&);
 template string stringsToString<unordered_set<string> >(const unordered_set<string>&);
 template void stringsToCSV<list<string> >(const list<string>&, string&, char);
-template void stringsToCSV<vector<string> >(const vector<string>&, string&,
-                                            char);
+template void stringsToCSV<vector<string> >(const vector<string>&, string&, char);
+template string commonprefix<vector<string>>(const vector<string>&values);
 #endif
 
 void stringToTokens(const string& str, vector<string>& tokens,
-                    const string& delims, bool skipinit)
+                    const string& delims, bool skipinit, bool allowempty)
 {
     string::size_type startPos = 0, pos;
 
@@ -367,7 +393,7 @@ void stringToTokens(const string& str, vector<string>& tokens,
         }
         if (pos == startPos) {
             // Dont' push empty tokens after first
-            if (tokens.empty()) {
+            if (allowempty || tokens.empty()) {
                 tokens.emplace_back();
             }
             startPos = ++pos;
@@ -571,7 +597,6 @@ string makeCString(const string& in)
     return out;
 }
 
-
 // Substitute printf-like percent cmds inside a string
 bool pcSubst(const string& in, string& out, const map<char, string>& subs)
 {
@@ -951,7 +976,7 @@ bool parsedateinterval(const string& s, DateInterval *dip)
         return false;
     }
 
-    vector<string>::const_iterator it = vs.begin();
+    auto it = vs.cbegin();
     if (*it == "P" || *it == "p") {
         it++;
         if (!parseperiod(it, vs.end(), &p1)) {
@@ -1221,7 +1246,7 @@ std::string SimpleRegexp::simpleSub(
     const std::string& in, const std::string& repl)
 {
     if (!ok()) {
-        return std::string();
+        return {};
     }
 
     int err;
@@ -1256,7 +1281,7 @@ bool SimpleRegexp::simpleMatch(const string& val) const
 string SimpleRegexp::getMatch(const string& val, int i) const
 {
     if (i > m->nmatch) {
-        return string();
+        return {};
     }
     return val.substr(m->matches[i].rm_so,
                       m->matches[i].rm_eo - m->matches[i].rm_so);
@@ -1329,3 +1354,5 @@ string valToString(const vector<CharFlags>& flags, unsigned int val)
 void smallut_init_mt()
 {
 }
+
+} // End namespace MedocUtils
